/* moin overrides to monobook styles */

/* moin uses #page rather than #content for the main page content.
setup #page as #content from the monobook.css and remove margins
and paddings from #content */

body {
    background: #f9f9f9 url('../img/headbg.jpg') 0px 0px no-repeat;
}

#page {
    margin: 2.8em 0 0 12.2em;
    padding: 0em 1em 1.5em 1em;
    background: White;
    border: 1px solid #aaaaaa;
    border-right: none;
    line-height: 1.5em;
    position: relative;
    z-index: 2;
}

#content {
    margin: 0;
    border: none;
    padding: none;
}

#p-personal li.pt-userpage {
    background: url('../img/user.gif') top left no-repeat;
    padding-left: 20px;
}


/* message set as usermessage from base css */

#message {
    background-color: #ffce7b;
    border: 1px solid #ffa500;
    color: Black;
    font-weight: bold;
    margin: 2em 0em 1em 0em;
    padding: 0.5em 1em;
    vertical-align: middle;
}

/* diff styling copied from modern theme */

.diff {
	width:99%;
}

.diff-header {
	font-weight: bold;
}

.diff-title {
	background-color: #C0C0C0;
}

.diff-added {
	background-color: #E0FFE0;
	vertical-align: sub;
}

.diff-removed {
	background-color: #FFFFE0;
	vertical-align: sub;
}

.diff-added span {
	background-color: #80FF80;
}

.diff-removed span {
	background-color: #FFFF80;
}

/* Spans for line-anchors - uses * html hack so that the rule only applies to
 * IE (where omitting the "display: none" triggers rendering bugs).
 */
* html span.anchor { display: none; }

/* IE6 has a bug with rendering of float elements. We workaround this bug by
 * assigning those elements a height attribute because we currently don't know
 * a better solution. This results in IE calculating the correct height of the
 * characters and displaying them correctly. We don't know any negative side
 * effects of this workaround:
 */
* html div#page, * html div#header { height: 0.001%; }

/* copied from the modern theme */

#credits, #version, #timings{
	margin: 5px 10px;
	padding: 0;
	text-align: center;
	font-size: 0.88em;
	color: #6C7680;
	font-size: 12px;
}

#credits li, #timings li {
	display: inline;
	padding: 0 2px;
	margin: 0 4px;
}

/* We use here dumb css1 ids because of IE suckiness */
#editor-textarea, #editor-comment {
    width: 100%;
}

div.codearea { /* the div makes the border */
    border: 1px dashed #2f6fab;
}

/* Mozilla specific rounded border effect */

#page {
    -moz-border-radius: 10px 0px 0px 10px;
}

.pBody {
    -moz-border-radius: 10px 10px 10px 10px;
}

#p-cactions li {
    -moz-border-radius: 10px 10px 0px 0px;
}

#p-cactions li a {
    -moz-border-radius: 10px 10px 0px 0px;
}

